@@ -23,8 +23,8 @@ class SkLearnLiftingFn(koopman_pipeline.EpisodeIndependentLiftingFn):
     - ``sklearn.preprocessing.MinMaxScaler``, or
     - ``sklearn.preprocessing.MaxAbsScaler``.
 
-    See [transformers]_ for more appropriate transformers (though not all have
-    been tested).
+    Any ``scikit-learn`` transformer [#tr]_ should be compatible, though not
+    all have been tested.
 
     Attributes
     ----------
@@ -49,7 +49,7 @@ class SkLearnLiftingFn(koopman_pipeline.EpisodeIndependentLiftingFn):
 
     References
     ----------
-    .. [transformers] https://scikit-learn.org/stable/modules/classes.html#module-sklearn.preprocessing  # noqa: E501
+    .. [#tr] https://scikit-learn.org/stable/modules/classes.html#module-sklearn.preprocessing
 
     Examples
     --------
@@ -61,9 +61,9 @@ class SkLearnLiftingFn(koopman_pipeline.EpisodeIndependentLiftingFn):
     SkLearnLiftingFn(transformer=StandardScaler())
     >>> X_msd_pp = std_scaler.transform(X_msd)
     >>> np.mean(X_msd_pp[:, 1:], axis=0)
-    array([ 1.99840144e-17, -3.10862447e-17, -1.55431223e-17])
+    array([...])
     >>> np.std(X_msd_pp[:, 1:], axis=0)
-    array([1., 1., 1.])
+    array([...])
     """
 
     def __init__(
@@ -224,7 +224,7 @@ class PolynomialLiftingFn(koopman_pipeline.EpisodeIndependentLiftingFn):
 class BilinearInputLiftingFn(koopman_pipeline.EpisodeIndependentLiftingFn):
     """Lifting function to generate bilinear products of the state and input.
 
-    As proposed in [bilinear]_. Given a state ``x`` and input::
+    As proposed in [BFV20]_. Given a state ``x`` and input::
 
         u = np.array([
             [u1],
@@ -236,10 +236,10 @@ class BilinearInputLiftingFn(koopman_pipeline.EpisodeIndependentLiftingFn):
 
         psi = np.array([
             [x],
+            [u],
             [x * u1],
             [x * u2],
             [x * u3],
-            [u].
         ])
 
     where the products are element-wise.
@@ -286,17 +286,16 @@ class BilinearInputLiftingFn(koopman_pipeline.EpisodeIndependentLiftingFn):
     def _transform_one_ep(self, X: np.ndarray) -> np.ndarray:
         states = X[:, :self.n_states_in_]
         inputs = X[:, self.n_states_in_:]
-        features = [states]
+        features = [states, inputs]
         for k in range(self.n_inputs_in_):
             features.append(states * inputs[:, [k]])
-        features.append(inputs)
         Xt = np.hstack(features)
         return Xt
 
     def _inverse_transform_one_ep(self, X: np.ndarray) -> np.ndarray:
         Xt = np.hstack((
             X[:, :self.n_states_in_],
-            X[:, self.n_states_out_ + self.n_inputs_out_ - self.n_inputs_in_:],
+            X[:, self.n_states_in_:self.n_states_in_ + self.n_inputs_in_],
         ))
         return Xt
 
